# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tunnel.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'tunnel.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0ctunnel.proto\x12\x0equinkgl.tunnel\"\x82\x01\n\rTunnelMessage\x12\x0f\n\x07node_id\x18\x01 \x01(\t\x12\x11\n\ttarget_id\x18\x02 \x01(\t\x12)\n\x04type\x18\x03 \x01(\x0e\x32\x1b.quinkgl.tunnel.MessageType\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\x12\x11\n\ttimestamp\x18\x05 \x01(\x03\"3\n\x0fRegisterPayload\x12\x0f\n\x07node_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"6\n\x10HeartbeatPayload\x12\x0f\n\x07node_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\"A\n\x0b\x43hatMessage\x12\x11\n\tsender_id\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"#\n\x0fPeerListPayload\x12\x10\n\x08peer_ids\x18\x01 \x03(\t\"-\n\x0c\x45rrorPayload\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xb7\x01\n\x13ICECandidatePayload\x12\x12\n\nfoundation\x18\x01 \x01(\t\x12\x11\n\tcomponent\x18\x02 \x01(\x05\x12\x10\n\x08protocol\x18\x03 \x01(\t\x12\x10\n\x08priority\x18\x04 \x01(\x05\x12\n\n\x02ip\x18\x05 \x01(\t\x12\x0c\n\x04port\x18\x06 \x01(\x05\x12\x0c\n\x04type\x18\x07 \x01(\t\x12\x17\n\x0frelated_address\x18\x08 \x01(\t\x12\x14\n\x0crelated_port\x18\t \x01(\x05\"\x91\x01\n\x0fSDPOfferPayload\x12\x0f\n\x07\x66rom_id\x18\x01 \x01(\t\x12\r\n\x05to_id\x18\x02 \x01(\t\x12\x37\n\ncandidates\x18\x03 \x03(\x0b\x32#.quinkgl.tunnel.ICECandidatePayload\x12\x12\n\nsession_id\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\x03\"\x92\x01\n\x10SDPAnswerPayload\x12\x0f\n\x07\x66rom_id\x18\x01 \x01(\t\x12\r\n\x05to_id\x18\x02 \x01(\t\x12\x37\n\ncandidates\x18\x03 \x03(\x0b\x32#.quinkgl.tunnel.ICECandidatePayload\x12\x12\n\nsession_id\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\x03*\x88\x01\n\x0bMessageType\x12\x0c\n\x08REGISTER\x10\x00\x12\r\n\tHEARTBEAT\x10\x01\x12\x10\n\x0cTEXT_MESSAGE\x10\x02\x12\r\n\tPEER_LIST\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\r\n\tSDP_OFFER\x10\x05\x12\x0e\n\nSDP_ANSWER\x10\x06\x12\x11\n\rICE_CANDIDATE\x10\x07\x32\x63\n\rTunnelService\x12R\n\x0eRegisterTunnel\x12\x1d.quinkgl.tunnel.TunnelMessage\x1a\x1d.quinkgl.tunnel.TunnelMessage(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tunnel_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MESSAGETYPE']._serialized_start=909
  _globals['_MESSAGETYPE']._serialized_end=1045
  _globals['_TUNNELMESSAGE']._serialized_start=33
  _globals['_TUNNELMESSAGE']._serialized_end=163
  _globals['_REGISTERPAYLOAD']._serialized_start=165
  _globals['_REGISTERPAYLOAD']._serialized_end=216
  _globals['_HEARTBEATPAYLOAD']._serialized_start=218
  _globals['_HEARTBEATPAYLOAD']._serialized_end=272
  _globals['_CHATMESSAGE']._serialized_start=274
  _globals['_CHATMESSAGE']._serialized_end=339
  _globals['_PEERLISTPAYLOAD']._serialized_start=341
  _globals['_PEERLISTPAYLOAD']._serialized_end=376
  _globals['_ERRORPAYLOAD']._serialized_start=378
  _globals['_ERRORPAYLOAD']._serialized_end=423
  _globals['_ICECANDIDATEPAYLOAD']._serialized_start=426
  _globals['_ICECANDIDATEPAYLOAD']._serialized_end=609
  _globals['_SDPOFFERPAYLOAD']._serialized_start=612
  _globals['_SDPOFFERPAYLOAD']._serialized_end=757
  _globals['_SDPANSWERPAYLOAD']._serialized_start=760
  _globals['_SDPANSWERPAYLOAD']._serialized_end=906
  _globals['_TUNNELSERVICE']._serialized_start=1047
  _globals['_TUNNELSERVICE']._serialized_end=1146
# @@protoc_insertion_point(module_scope)
